@@ -1,14 +1,5 @@
 $(function() {
 
-    /* Pilltabs */
-    /* Automatically add active class to first elements */
-    $(".nav-pilltabs").each(function() {
-      $(this).find("li").first().addClass("active")
-    });
-    $(".tab-content").each(function() {
-      $(this).find(".tab-pane").first().addClass("active")
-    });
-
     /* Menu */
     $('#toc ul').first().addClass('nav');
     $('#toc ul li').addClass('withripple').first().addClass("active");
